#	This file is part of SurrealServices.
#
#	SurrealServices is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	SurrealServices is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with SurrealServices; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package SrSv::Util;

use strict;

use Exporter 'import';
BEGIN { our @EXPORT = qw(min max makeSeqList) }

sub min($$) {
	return ($_[0] < $_[1] ? $_[0] : $_[1]);
}
sub max($$) {
	return ($_[0] > $_[1] ? $_[0] : $_[1]);
}

sub makeSeqList(@) { 
	my @nums;
	foreach my $arg (@_) {
		foreach my $parm (split(',', $arg)) {
			if ($parm =~ /^(\d+)(?:-|\.\.)(\d+)$/) {
				push @nums, min($1, $2)..max($1, $2);
			} elsif(misc::isint($parm)) {
				push @nums, $parm;
			} else {
				# just ignore it. we could try throwing an error.
			}
		}
	}
	# map is a uniqify in case of duplicates
	# the sort is modified to sort numerically rather than by string.
	return sort( {$a <=> $b}  keys %{{ map { $_ => 1 } @nums }} );
}

1;
